# video_comparison

This creates a streamlit element of video comparison
![Alt Text](demo.gif)

Using a streamlit app you can create a nice before/after video comparison tool as in: 
https://vimeo.com/761978157/df22fa4e7e

install by running 
`pip install git+git://github.vimeows.com/yedidya-hyams/video_comparison#egg=video_compare
`